Struct soup::ServerListenOptions
source · pub struct ServerListenOptions(_);Implementations
sourceimpl ServerListenOptions
impl ServerListenOptions
sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get the value for a flag from its stringified name.
Names are case-sensitive, so must correspond exactly to the identifier given to the flag.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn insert(&mut self, other: Self)
pub fn insert(&mut self, other: Self)
Inserts the specified flags in-place.
This method is equivalent to union.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
Removes the specified flags in-place.
This method is equivalent to difference.
sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
Toggles the specified flags in-place.
This method is equivalent to symmetric_difference.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Calculating self bitwise and (&) other, including
any bits that don’t correspond to a defined flag.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Calculates self bitwise or (|) other, including
any bits that don’t correspond to a defined flag.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Calculates self bitwise and (&!) the bitwise negation of other,
including any bits that don’t correspond to a defined flag.
This method is not equivalent to a & !b when there are bits set that
don’t correspond to a defined flag. The ! operator will unset any
bits that don’t correspond to a flag, so they’ll always be unset by a &! b,
but respected by a.difference(b).
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Calculates self bitwise exclusive or (^) other,
including any bits that don’t correspond to a defined flag.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Calculates the bitwise negation (!) of self,
unsetting any bits that don’t correspond to a defined flag.
sourceimpl ServerListenOptions
impl ServerListenOptions
sourcepub const fn iter(&self) -> Iter<ServerListenOptions>
pub const fn iter(&self) -> Iter<ServerListenOptions>
Iterate over enabled flag values.
sourcepub const fn iter_names(&self) -> IterNames<ServerListenOptions>
pub const fn iter_names(&self) -> IterNames<ServerListenOptions>
Iterate over enabled flag values with their stringified names.